<?php
/**
* 2007-2016 Tribu and co
* @author Tribu And Co. (contact@tribu-and-co.fr)
* @version 1.0
* User: Tribu And Co
* Date: 04/03/2019
*/
if (!defined('_PS_VERSION_')) {
	exit;
}


class Tc_pricefilter extends Module {

	private $sql;

	public function __construct()
	{
		$this->tab = 'front_office_features';
		$this->name = 'tc_pricefilter';
		$this->version = '1.0.0';
		$this->author = 'Tribu And Co (tribu-and-co.fr)';

		parent::__construct();

		$this->displayName = $this->trans('Filtre par prix (range slider)', array(), 'Modules.Pricefilter.Admin');
		$this->description = $this->trans("Permet de filtrer les produits par prix à l'aide d'un range slider", array(), 'Modules.Pricefilter.Admin');
		$this->ps_versions_compliancy = array('min' => '1.7.2.0', 'max' => _PS_VERSION_);
				
				
		$this->confirmUninstall = $this->trans('Are you sure you want to uninstall this module?', array(), 'Modules.Pricefilter.Admin');
		$this->sql = array();

	}

	public function install()
	{
		$return = parent::install() &&
			$this->registerHook('header');
		$this->addTemplatesToTheme('install');

		return (bool) $return;
	}

	public function uninstall()
	{
		$this->removeTemplates();
		return parent::uninstall();

	}

	public function enable($force_all = false){
		$this->addTemplatesToTheme('enable');
		return parent::enable();
	}

	public function disable($force_all = false){
		$this->removeTemplates();
		return parent::disable();
	}

	public function hookdisplayHeader(){
		$this->context->controller->addCSS($this->_path.'css/ion.rangeSlider.min.css');
		$this->context->controller->addJS($this->_path.'js/ion.rangeSlider.min.js');
		$this->context->controller->addJS($this->_path.'js/pricefilter.js');

		if(Configuration::get('PS_LAYERED_SHOW_QTIES', $this->context->language->id) == 1)
			$show_qties = true;
		else
			$show_qties = false;

		$products = Product::getProducts($this->context->language->id,0,0,'price','asc',false,true,$this->context);

		$min = $products[0]['price'];
		end($products);
		$max = $products[key($products)]['price'];
		reset($products);

		$this->context->smarty->assign(['show_qties'=>$show_qties,'minPriceRange'=>$min,'maxPriceRange'=>$max]);
	}

	//rename and copy needed theme's templates
	public function addTemplatesToTheme($action){
		if($action == 'install'){
			if(file_exists ( _PS_THEME_DIR_.'templates/catalog/_partials/facets.tpl')){
				chmod(_PS_THEME_DIR_.'templates/catalog/_partials/facets.tpl',0666);
				rename(_PS_THEME_DIR_.'templates/catalog/_partials/facets.tpl',_PS_THEME_DIR_.'templates/catalog/_partials/facets_old.tpl');
				copy(_PS_ROOT_DIR_.'/modules/'.$this->name.'/views/facets.tpl',_PS_ROOT_DIR_._THEME_DIR_.'templates/catalog/_partials/facets.tpl');
				chmod(_PS_THEME_DIR_.'templates/catalog/_partials/facets.tpl',0666);
			}
		}
		if($action == 'enable'){
			if(file_exists ( _PS_THEME_DIR_.'templates/catalog/_partials/facets.tpl')) {
				rename(_PS_THEME_DIR_ . 'templates/catalog/_partials/facets.tpl', _PS_THEME_DIR_ . 'templates/catalog/_partials/facets_old.tpl');
				copy(_PS_ROOT_DIR_ . '/modules/' . $this->name . '/views/facets.tpl', _PS_ROOT_DIR_ . _THEME_DIR_ . 'templates/catalog/_partials/facets.tpl');
			}
		}
	}

	//go back to originals theme's templates
	public function removeTemplates(){
		if(file_exists ( _PS_THEME_DIR_.'templates/catalog/_partials/facets_old.tpl'))
			rename(_PS_THEME_DIR_.'templates/catalog/_partials/facets_old.tpl',_PS_THEME_DIR_.'templates/catalog/_partials/facets.tpl');
	}

	// Create module's table
	public function loadTables()
	{
		$state = true;
		$this->sql[_DB_PREFIX_.'tribuandco'] = 'CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'tribuandco` (
			  `id` int(11) NOT NULL AUTO_INCREMENT,
			  PRIMARY KEY (`id`)
			) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=utf8;';

		foreach ($this->sql as $query)
			$state &= Db::getInstance()->execute($query);

		return $state;
	}

	public function unloadTables()
	{
		$state = true;

		foreach ($this->sql as $name => $v)
			$state &= Db::getInstance()->execute('DROP TABLE IF EXISTS '.$name);

		return $state;
	}

	private function installModuleTab($tabClass, $tabName, $idTabParent){
		@copy(_PS_MODULE_DIR_ . $this->name . '/logo.png',
			_PS_IMG_DIR_ . 't/' . $tabClass . '.png');
		$tab = new Tab();
		$tab->name = $tabName;
		$tab->class_name = $tabClass;
		$tab->module = $this->name;
		$tab->id_parent = $idTabParent;
		if (!$tab->save())
			return false;
		return true;
	}

	private function uninstallModuleTab($tabClass){
		$idTab = Tab::getIdFromClassName($tabClass);
		if ($idTab != 0) {
			$tab = new Tab($idTab);
			$tab->delete();
			@unlink(_PS_IMG_DIR . "t/" . $tabClass . ".png");
			return true;
		}
		return false;
	}


}